#[derive(EnumFromStr)]Expand description
Implements std::str::FromStr for enum, which has same constraints as EnumToString and works in the opposite direction.
#[derive(EnumFromStr)]Implements std::str::FromStr for enum, which has same constraints as EnumToString and works in the opposite direction.